[COMMIT LOGREPORT] service/all/lib/Lire Syslog.pm,1.13,1.14

Joost van Baal vanbaal at users.sourceforge.net
Fri Oct 28 11:50:50 CEST 2005


Update of /cvsroot/logreport/service/all/lib/Lire
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv20509

Modified Files:
	Syslog.pm 
Log Message:
Emeric Laroche knows what syslog deamon this is.  Tnx Mric!

Index: Syslog.pm
===================================================================
RCS file: /cvsroot/logreport/service/all/lib/Lire/Syslog.pm,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -r1.13 -r1.14
--- Syslog.pm	17 May 2004 17:05:18 -0000	1.13
+++ Syslog.pm	28 Oct 2005 09:50:47 -0000	1.14
@@ -377,7 +377,7 @@
 #------------------------------------------------------------------------
 # Method parse_unknown_syslog ($line)
 #
 # Parse messages from an unknown syslog daemon that keep the encoded
 # facility and has a year:
 #
 # <166>Jul 22 2002 00:01:14: %PIX-6-302001:
@@ -639,11 +639,10 @@
 
     MM/DD/YY HH:MM:SS Process(Pid): Level: Message
 
-=item Unknown Syslog daemon
+=item RFC 3164-compliant Syslog daemon
 
-A format from an unknown syslog daemon which includes the encoded
-priority and the year in the date. (Note: if you know the name of the
-syslog daemon that uses this format, please let us know!)
+A format from RFC 3164-compliant Syslog daemons which includes the encoded
+priority and the year in the date.  RFC 3164 defines the "BSD Syslog Protocol".
 
     <Priority>MMM DD YYYY HH:MM:SS: Process[Pid]: Message
 
@@ -377,7 +377,7 @@
 # Method parse_unknown_syslog ($line)
 #
-# Parse messages from an unknown syslog daemon that keep the encoded
+# Parse messages from rfc 3164-compliant syslog daemons that keep the encoded
 # facility and has a year:
 #

-- 
To UNSUBSCRIBE, email to commit-request at logreport.org with a subject of 
"unsubscribe". Trouble? Send an email with subject "help" to 
commit-request at logreport.org



More information about the Commit mailing list